`gsi_sim`, developed by assigner co-author Eric C. Anderson, is an external command-line program and is not installed by the R package. This function searches the active `PATH` and validates that the executable can be started.
`gsi_sim`, developed by assigner co-author Eric C. Anderson, is an external command-line program and is not installed by the R package. This function searches the active `PATH` and validates that the executable can be started.